@@ -101,7 +101,7 @@ plot.secr <- function (x, newdata = NULL, add = FALSE,
                 grad <- matrix(nrow = length(xval), ncol = length(x$fit$par))  ## beta pars
                 if (is.null(newdata)) {
                     # newdata <- secr.make.newdata (x)
-                    newdata <- make.newdata (x)
+                    newdata <- makeNewData(x)
                 }
                 parnamvec <- parnames(x$detectfn)
                 ## 2019-01-25 added beta0
